@@ -30,3 +30,6 @@ ARCHIVE_PKG_NAME = 'data.tar.gz'
 UI_FIELDS_IN_MANIFEST = {'description': 'description',
                          'type': 'full_service_name',
                          'name': 'service_display_name'}
+
+SERVICE_DEFINITIONS_FOLDER_NAME = 'service_definitions'
+CACHE_FOLDER_NAME = 'cache'
